@@ -26,7 +26,7 @@ except NameError: # pragma no cover
     _unicode = str
 
 __author__ = 'Martin Blech'
-__version__ = '0.4.4'
+__version__ = '0.4.6'
 __license__ = 'MIT'
 
 class ParsingInterrupted(Exception): pass
@@ -41,7 +41,8 @@ class _DictSAXHandler(object):
                  force_cdata=False,
                  cdata_separator='',
                  postprocessor=None,
-                 dict_constructor=OrderedDict):
+                 dict_constructor=OrderedDict,
+                 strip_whitespace=True):
         self.path = []
         self.stack = []
         self.data = None
@@ -49,12 +50,13 @@ class _DictSAXHandler(object):
         self.item_depth = item_depth
         self.xml_attribs = xml_attribs
         self.item_callback = item_callback
-        self.attr_prefix = attr_prefix;
+        self.attr_prefix = attr_prefix
         self.cdata_key = cdata_key
         self.force_cdata = force_cdata
         self.cdata_separator = cdata_separator
         self.postprocessor = postprocessor
         self.dict_constructor = dict_constructor
+        self.strip_whitespace = strip_whitespace
 
     def startElement(self, name, attrs):
         attrs = self.dict_constructor(zip(attrs[0::2], attrs[1::2]))
@@ -81,6 +83,8 @@ class _DictSAXHandler(object):
         if len(self.stack):
             item, data = self.item, self.data
             self.item, self.data = self.stack.pop()
+            if self.strip_whitespace and data is not None:
+                data = data.strip() or None
             if data and self.force_cdata and item is None:
                 item = self.dict_constructor()
             if item is not None:
@@ -117,7 +121,7 @@ class _DictSAXHandler(object):
             item[key] = data
         return item
 
-def parse(xml_input, *args, **kwargs):
+def parse(xml_input, encoding='utf-8', *args, **kwargs):
     """Parse the given XML input and convert it into a dictionary.
 
     `xml_input` can either be a `string` or a file-like object.
@@ -154,7 +158,7 @@ def parse(xml_input, *args, **kwargs):
         >>> def handle(path, item):
         ...     print 'path:%s item:%s' % (path, item)
         ...     return True
-        ... 
+        ...
         >>> xmltodict.parse(\"\"\"
         ... <a prop="x">
         ...   <b>1</b>
@@ -183,9 +187,11 @@ def parse(xml_input, *args, **kwargs):
     parser.StartElementHandler = handler.startElement
     parser.EndElementHandler = handler.endElement
     parser.CharacterDataHandler = handler.characters
-    if hasattr(xml_input, 'read'):
+    try:
         parser.ParseFile(xml_input)
-    else:
+    except (TypeError, AttributeError):
+        if isinstance(xml_input, _unicode):
+            xml_input = xml_input.encode(encoding)
         parser.Parse(xml_input, True)
     return handler.item
 
@@ -229,7 +235,6 @@ def _emit(key, value, content_handler,
             content_handler.characters(cdata)
         content_handler.endElement(key)
 
-
 def unparse(item, output=None, encoding='utf-8', **kwargs):
     ((key, value),) = item.items()
     must_return = False
